﻿local _, HNDB = ...
local ADDON_NAME = 'HandyNotes_DataBroker'
local HandyNotes = LibStub('AceAddon-3.0'):GetAddon('HandyNotes', true)

if not HandyNotes then return end
HNDB = LibStub('AceAddon-3.0'):NewAddon(ADDON_NAME, 'AceConsole-3.0', 'AceEvent-3.0')
local LDB = LibStub('LibDataBroker-1.1')

local defaults = {
    profile = {
        minimap = {}
    }
}

local mainDB = LibStub('AceDB-3.0'):New('HandyNotesDB').profile;
local _icon = LibStub('LibDBIcon-1.0')
local tooltip = 
[[Left Click to toggle HandyNotes.
Right Click to open settings.]]

function HNDB:Toggle()
    -- Taken from HandyNotes_WorldMapButton

    if HandyNotes:IsEnabled() then
        -- print('HandyNotes disabled')
        mainDB.enabled = false
        HandyNotes:Disable();
    else
        -- print('HandyNotes enabled')
        mainDB.enabled = true
        HandyNotes:Enable();
    end
end

-- Taken from LibDBIcon
local function getAnchors(frame)
	local x, y = frame:GetCenter()
	if not x or not y then return "CENTER" end
	local hhalf = (x > UIParent:GetWidth()*2/3) and "RIGHT" or (x < UIParent:GetWidth()/3) and "LEFT" or ""
	local vhalf = (y > UIParent:GetHeight()/2) and "TOP" or "BOTTOM"
	return vhalf..hhalf, frame, (vhalf == "TOP" and "BOTTOM" or "TOP")..hhalf
end

local function setTooltipText(tt)
    local status = HandyNotes:IsEnabled() and 'Enabled' or 'Disabled'
    tt:AddLine('HandyNotes - '..status, 1, 1, 1);
    tt:AddLine(' ');
    tt:AddLine(tooltip)
end

function HNDB:OnInitialize()
    local ops = LibStub('AceConfigRegistry-3.0'):GetOptionsTable('HandyNotes', 'dialog', ADDON_NAME..'-1.0.0')
    ops['args']['overall_settings']['args']['minimap_button'] = {
        type = "toggle",
        name = 'Minimap Button',
        desc = 'Toggles the minimap button',
        get = function(info) return not self.db.profile.minimap.hide end,
        set = function(info, v)
            self.db.profile.minimap.hide = not v
            _icon:Refresh(ADDON_NAME, self.db.profile.minimap)
        end,
        order = 99,
    }
    local LDBObj = LDB:NewDataObject(ADDON_NAME, {
        type = 'launcher',
        label = 'HandyNotes',
        icon = 'Interface/Icons/INV_Box_01',
        OnClick = function(obj, button, down)
            local Dialog = LibStub('AceConfigDialog-3.0')
            if button == 'LeftButton' then
                self:Toggle()
                -- Reopen dialog to refresh
                if Dialog.OpenFrames['HandyNotes'] then
                    Dialog:Open('HandyNotes')
                end
            elseif button == 'RightButton' then
                Dialog:Open('HandyNotes')
            end
        end,
        OnTooltipShow = function(tt)
            setTooltipText(tt)
        end	
    })
    self.db = LibStub("AceDB-3.0"):New(ADDON_NAME..'DB', defaults)
	_icon:Register(ADDON_NAME, LDBObj, self.db.profile.minimap)
end
